aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/ApiClient
diff options
context:
space:
mode:
authorLuke Pulverenti <luke.pulverenti@gmail.com>2013-07-29 16:44:49 -0400
committerLuke Pulverenti <luke.pulverenti@gmail.com>2013-07-29 16:44:49 -0400
commit82352d13e48188e4d70b0d01322b54661703c924 (patch)
tree26e2d9399cf542bf310ccc71daa314b8d417a4de /MediaBrowser.Model/ApiClient
parent0fb515d209348406274c44431162b1813761cac0 (diff)
updated nuget
Diffstat (limited to 'MediaBrowser.Model/ApiClient')
-rw-r--r--MediaBrowser.Model/ApiClient/IApiClient.cs42
1 files changed, 10 insertions, 32 deletions
diff --git a/MediaBrowser.Model/ApiClient/IApiClient.cs b/MediaBrowser.Model/ApiClient/IApiClient.cs
index b99773e4d5..0976da05ca 100644
--- a/MediaBrowser.Model/ApiClient/IApiClient.cs
+++ b/MediaBrowser.Model/ApiClient/IApiClient.cs
@@ -609,15 +609,6 @@ namespace MediaBrowser.Model.ApiClient
string GetPersonImageUrl(BaseItemPerson item, ImageOptions options);
/// <summary>
- /// Gets the person image URL.
- /// </summary>
- /// <param name="item">The item.</param>
- /// <param name="options">The options.</param>
- /// <returns>System.String.</returns>
- /// <exception cref="ArgumentNullException">item</exception>
- string GetPersonImageUrl(BaseItemDto item, ImageOptions options);
-
- /// <summary>
/// Gets an image url that can be used to download an image from the api
/// </summary>
/// <param name="name">The name of the person</param>
@@ -644,15 +635,6 @@ namespace MediaBrowser.Model.ApiClient
string GetYearImageUrl(int year, ImageOptions options);
/// <summary>
- /// Gets the genre image URL.
- /// </summary>
- /// <param name="item">The item.</param>
- /// <param name="options">The options.</param>
- /// <returns>System.String.</returns>
- /// <exception cref="ArgumentNullException">item</exception>
- string GetGenreImageUrl(BaseItemDto item, ImageOptions options);
-
- /// <summary>
/// Gets an image url that can be used to download an image from the api
/// </summary>
/// <param name="name">The name.</param>
@@ -662,33 +644,29 @@ namespace MediaBrowser.Model.ApiClient
string GetGenreImageUrl(string name, ImageOptions options);
/// <summary>
/// Gets the studio image URL.
/// </summary>
- /// <param name="item">The item.</param>
+ /// <param name="name">The name.</param>
/// <param name="options">The options.</param>
/// <returns>System.String.</returns>
- /// <exception cref="ArgumentNullException">item</exception>
- string GetStudioImageUrl(BaseItemDto item, ImageOptions options);
+ string GetMusicGenreImageUrl(string name, ImageOptions options);
/// <summary>
/// Gets an image url that can be used to download an image from the api
/// </summary>
/// <param name="name">The name.</param>
/// <param name="options">The options.</param>
/// <returns>System.String.</returns>
- /// <exception cref="ArgumentNullException">name</exception>
- string GetStudioImageUrl(string name, ImageOptions options);
-
+ string GetGameGenreImageUrl(string name, ImageOptions options);
+
/// <summary>
- /// Gets the artist image URL.
+ /// Gets an image url that can be used to download an image from the api
/// </summary>
- /// <param name="item">The item.</param>
+ /// <param name="name">The name.</param>
/// <param name="options">The options.</param>
/// <returns>System.String.</returns>
- /// <exception cref="ArgumentNullException">item
- /// or
- /// options</exception>
- string GetArtistImageUrl(BaseItemDto item, ImageOptions options);
+ /// <exception cref="ArgumentNullException">name</exception>
+ string GetStudioImageUrl(string name, ImageOptions options);
/// <summary>
/// Gets the artist image URL.
@@ -662,33 +644,29 @@ namespace MediaBrowser.Model.ApiClient
string GetGenreImageUrl(string name, ImageOptions options);
/// <summary>
- /// Gets the studio image URL.
+ /// Gets the music genre image URL.
/// </summary>
@@ -662,33 +644,29 @@ namespace MediaBrowser.Model.ApiClient
/// <summary>
- /// Gets an image url that can be used to download an image from the api
+ /// Gets the game genre image URL.
/// </summary>
/// <param name="name">The name.</param>